<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="mn">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.grub2!message" line="0"/>
			<source>Authentication is required to change the grub configuration</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.grub2!description" line="0"/>
			<source>Change the grub configuration</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.grub2.prepare-gfxmode-detect!message" line="0"/>
			<source>Authentication is required to prepare grub display resolution detection</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.grub2.prepare-gfxmode-detect!description" line="0"/>
			<source>Prepare grub display resolution detection</source>
			<translation type="unfinished"/>
		</message>
	</context>
</TS>